@@ -78,8 +78,8 @@ def pair_handling_message(fetcher, msg, compute_minute_signal=True, compute_day_
                     ia_day_signal = fetcher.launchDaySequential()
 
             if (len(fetcher.day_np.shape) > 1 and len(fetcher.day_np) > 3):
-                #print('last three days')
-                #print(fetcher.day_np[-3:, :])
+                print('last three days signals nan numbers')
+                print(np.isnan(fetcher.day_np[-3:, :]).sum(axis=1))
                 print('day ia new signal computation for the bot ' + str(ia_day_signal))
             print('updating bot position for pair '+ str(fetcher.pair) + ' and signal '+str(ia_day_signal))
             fetcher.bot.update_position(fetcher.pair, ia_day_signal)
@@ -189,8 +189,8 @@ def pair_handling_message(fetcher, msg, compute_minute_signal=True, compute_day_
                 else:
                     ia_minute_signal = fetcher.launchMinuteSequential()
             if (len(fetcher.minute_np.shape)>1 and len(fetcher.minute_np)>3):
-                #print('last three minutes '+minute_name)
-                #print(fetcher.minute_np[-3:,:])
+                print(f'last three minutes {minute_name} nan numbers')
+                print(np.isnan(fetcher.minute_np[-3:,:]).sum(axis=1))
                 print('minute ia signal ' + str(ia_minute_signal))
         # we clear every former minutes
         high_dict.clear()
